This package contains no source itself, but instead acts as a shortcut for installing all 
available submodules within the birdwell namespace utility library. Currently, this includes:
birdwell-utils, birdwell-net, birdwell-mapping, and birdwell-database.
